# Contributing

Welcome to this catalog project! This page provides information for contributors.

## Documentation

This catalog is built using the [chartbook](https://backofficedev.github.io/chartbook/) Python package,
which generates documentation from pipeline specifications defined in `chartbook.toml` files.

For detailed documentation on how to use chartbook, including:
- How to configure pipelines
- How to add charts and dataframes
- How to customize the documentation theme

Please visit the [chartbook documentation](https://backofficedev.github.io/chartbook/).
